# Templates
These will eventually be the default templates that GitHub presents when creating a new Issue or Pull Request.

## Issue Template
    <!-- Uncomment the section that is applicable to your issue. -->
    
    <!-- Feature Suggestion
    ## Checklist

    - [ ] This feature does not already exist.
    - [ ] This feature has not been requested before.
    
    -->

    <!-- Error/Bug in code:
    ## Checklist

    - [ ] Same issue has not been opened before.

    ## Expected Behavior


    ## Actual Behavior


    ## Steps to Reproduce the Problem

      1. 
      2. 
      3.

    ## What I've tried so far:


    ## Specifications

      - Crawler Version:
      - Platform:
      - Dependency Versions:
    -->

## PR Template
    <!-- Please double-check that this entire form is filled out before submitting your PR. -->
    <!-- Uncomment sections applicable to your Pull. -->
    
    ## Checklist
    
    - [ ] This Pull will not add the same thing as another currently-open request.
    - [ ] Your Pull was made against the `rivermont:dev` branch and not `rivermont:master`.
    - [ ] This Pull does not commit any keys, passwords, personal data, or other private information.
    - [ ] I updated lines 20 and 21 in the README to reflect any changed I made.

    <!-- New feature:
    - [ ] I wrote at least some documentation for this feature.
    -->
